# EventumContentManager
Content manager for Eventum

## Overview
Package contains functions to manage (list, create, read, delete) content such as:
1. Configuration files
2. Templates
3. Samples
4. Time patterns
5. Compose configuration files

Content directory is `~/.eventum/content` (ignored in case of absolute path).

## Installation
```bash
pip install eventum-content-manager
```
